pub struct FixedMontyMultiplier<'a, const LIMBS: usize>(&'a FixedMontyParams<LIMBS>);Tuple Fields
0: &'a FixedMontyParams<LIMBS>Trait Implementations
Sourceimpl<'a, const LIMBS: usize> AmmMultiplier<'a> for FixedMontyMultiplier<'a, LIMBS>
impl<'a, const LIMBS: usize> AmmMultiplier<'a> for FixedMontyMultiplier<'a, LIMBS>
Sourcefn mul_amm_assign(&mut self, a: &mut Uint<LIMBS>, b: &Uint<LIMBS>)
fn mul_amm_assign(&mut self, a: &mut Uint<LIMBS>, b: &Uint<LIMBS>)
Perform an “Almost Montgomery Multiplication”, assigning the product to a.
NOTE: the resulting output will be reduced to the bit length of the modulus, but not fully reduced and may exceed the modulus. A final reduction is required to ensure AMM results are fully reduced, and should not be exposed outside the internals of this crate.
Sourcefn square_amm_assign(&mut self, a: &mut Uint<LIMBS>)
fn square_amm_assign(&mut self, a: &mut Uint<LIMBS>)
Perform a squaring using “Almost Montgomery Multiplication”, assigning the result to a.
NOTE: the resulting output will be reduced to the bit length of the modulus, but not fully reduced and may exceed the modulus. A final reduction is required to ensure AMM results are fully reduced, and should not be exposed outside the internals of this crate.
Sourceimpl<'a, const LIMBS: usize> Clone for FixedMontyMultiplier<'a, LIMBS>
impl<'a, const LIMBS: usize> Clone for FixedMontyMultiplier<'a, LIMBS>
Sourcefn clone(&self) -> FixedMontyMultiplier<'a, LIMBS>
fn clone(&self) -> FixedMontyMultiplier<'a, LIMBS>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'a, const LIMBS: usize> Debug for FixedMontyMultiplier<'a, LIMBS>
impl<'a, const LIMBS: usize> Debug for FixedMontyMultiplier<'a, LIMBS>
Sourceimpl<'a, const LIMBS: usize> From<&'a MontyParams<Uint<LIMBS>>> for FixedMontyMultiplier<'a, LIMBS>
impl<'a, const LIMBS: usize> From<&'a MontyParams<Uint<LIMBS>>> for FixedMontyMultiplier<'a, LIMBS>
Sourcefn from(source: &'a FixedMontyParams<LIMBS>) -> Self
fn from(source: &'a FixedMontyParams<LIMBS>) -> Self
Sourceimpl<'a, const LIMBS: usize> MontyMultiplier<'a> for FixedMontyMultiplier<'a, LIMBS>
impl<'a, const LIMBS: usize> MontyMultiplier<'a> for FixedMontyMultiplier<'a, LIMBS>
Sourcefn mul_assign(&mut self, lhs: &mut Self::Monty, rhs: &Self::Monty)
fn mul_assign(&mut self, lhs: &mut Self::Monty, rhs: &Self::Monty)
Performs a Montgomery multiplication, assigning a fully reduced result to lhs.
Sourcefn square_assign(&mut self, lhs: &mut Self::Monty)
fn square_assign(&mut self, lhs: &mut Self::Monty)
Performs a Montgomery squaring, assigning a fully reduced result to lhs.